(self.webpackChunk_flybrainlab_neuromynerva=self.webpackChunk_flybrainlab_neuromynerva||[]).push([[915],{9915:(r,e)=>{e.parse=e.decode=function(r){var e={},t=e,a=null,i=/^\[([^\]]*)\]$|^([^=]+)(=(.*))?$/i;return r.split(/[\r\n]+/g).forEach((function(r,n,o){if(r&&!r.match(/^\s*[;#]/)){var f=r.match(i);if(f){if(void 0!==f[1])return"__proto__"===(a=c(f[1]))?void(t={}):void(t=e[a]=e[a]||{});var s=c(f[2]);if("__proto__"!==s){var u=!f[3]||c(f[4]);switch(u){case"true":case"false":case"null":u=JSON.parse(u)}if(s.length>2&&"[]"===s.slice(-2)){if("__proto__"===(s=s.substring(0,s.length-2)))return;t[s]?Array.isArray(t[s])||(t[s]=[t[s]]):t[s]=[]}Array.isArray(t[s])?t[s].push(u):t[s]=u}}}})),Object.keys(e).filter((function(r,t,a){if(!e[r]||"object"!=typeof e[r]||Array.isArray(e[r]))return!1;var i=n(r),c=e,o=i.pop(),f=o.replace(/\\\./g,".");return i.forEach((function(r,e,t){"__proto__"!==r&&(c[r]&&"object"==typeof c[r]||(c[r]={}),c=c[r])})),(c!==e||f!==o)&&(c[f]=e[r],!0)})).forEach((function(r,t,n){delete e[r]})),e},e.stringify=e.encode=function r(e,a){var c=[],o="";"string"==typeof a?a={section:a,whitespace:!1}:(a=a||{}).whitespace=!0===a.whitespace;var f=a.whitespace?" = ":"=";return Object.keys(e).forEach((function(r,n,a){var s=e[r];s&&Array.isArray(s)?s.forEach((function(e){o+=i(r+"[]")+f+i(e)+"\n"})):s&&"object"==typeof s?c.push(r):o+=i(r)+f+i(s)+t})),a.section&&o.length&&(o="["+i(a.section)+"]"+t+o),c.forEach((function(i,c,f){var s=n(i).join("\\."),u=(a.section?a.section+".":"")+s,p=r(e[i],{section:u,whitespace:a.whitespace});o.length&&p.length&&(o+=t),o+=p})),o},e.safe=i,e.unsafe=c;var t="win32"==={cwd:()=>"/"}.platform?"\r\n":"\n";function n(r){return r.replace(/\1/g,"LITERAL\\1LITERAL").replace(/\\\./g,"").split(/\./).map((function(r){return r.replace(/\1/g,"\\.").replace(/\2LITERAL\\1LITERAL\2/g,"")}))}function a(r){return'"'===r.charAt(0)&&'"'===r.slice(-1)||"'"===r.charAt(0)&&"'"===r.slice(-1)}function i(r){return"string"!=typeof r||r.match(/[=\r\n]/)||r.match(/^\[/)||r.length>1&&a(r)||r!==r.trim()?JSON.stringify(r):r.replace(/;/g,"\\;").replace(/#/g,"\\#")}function c(r,e){if(!a(r=(r||"").trim())){for(var t=!1,n="",i=0,c=r.length;i<c;i++){var o=r.charAt(i);if(t)-1!=="\\;#".indexOf(o)?n+=o:n+="\\"+o,t=!1;else{if(-1!==";#".indexOf(o))break;"\\"===o?t=!0:n+=o}}return t&&(n+="\\"),n.trim()}"'"===r.charAt(0)&&(r=r.substr(1,r.length-2));try{r=JSON.parse(r)}catch(r){}return r}}}]);